Package hbsae provides functions to compute small area estimates based on the basic unit-level and area-level models. The models are fit and small area estimates are computed in a hierarchical Bayesian way, using numerical integration.
The main function that does most of the computational
work is fSAE.Unit. Function
fSAE is provided as a more convenient
interface to fSurvReg,
fSAE.Area and fSAE.Unit.